@@ -11,6 +11,7 @@ from django.urls import reverse_lazy
 from django.utils.translation import gettext_lazy as _
 
 import tcms
+from tcms.utils.secrets import get_secret
 
 # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 # ~~ You have to override the following settings in product.py
@@ -27,12 +28,12 @@ SECRET_KEY = "^8y!)$0t7yq2+65%&_#@i^_o)eb3^q--y_$e7a_=t$%$1i)zuv"  # nosec:B105
 # Database settings
 DATABASES = {
     "default": {
-        "ENGINE": os.environ.get("KIWI_DB_ENGINE", "django.db.backends.mysql"),
-        "NAME": os.environ.get("KIWI_DB_NAME", "kiwi"),
-        "USER": os.environ.get("KIWI_DB_USER", "kiwi"),
-        "PASSWORD": os.environ.get("KIWI_DB_PASSWORD", "kiwi"),
-        "HOST": os.environ.get("KIWI_DB_HOST", ""),
-        "PORT": os.environ.get("KIWI_DB_PORT", ""),
+        "ENGINE": get_secret("KIWI_DB_ENGINE", "django.db.backends.mysql"),
+        "NAME": get_secret("KIWI_DB_NAME", "kiwi"),
+        "USER": get_secret("KIWI_DB_USER", "kiwi"),
+        "PASSWORD": get_secret("KIWI_DB_PASSWORD", "kiwi"),
+        "HOST": get_secret("KIWI_DB_HOST", ""),
+        "PORT": get_secret("KIWI_DB_PORT", ""),
         "OPTIONS": {},
     },
 }
@@ -158,6 +159,21 @@ MIDDLEWARE = [
 # and tcms/issuetracker/azure_boards.py
 AZURE_BOARDS_API_VERSION = os.environ.get("AZURE_BOARDS_API_VERSION", "6.0")
 
+# A list of fully qualified dotted paths to functions which will be executed after
+# a new issue has been automatically opened in an external bug tracker via the
+# 1-click bug report integration!
+# See tcms.issuetracker.base.IssueTrackerType.post_process_new_issue() and
+# tcms.issuetracker.tests.redmine_post_processing for hints!
+EXTERNAL_ISSUE_POST_PROCESSORS = []
+
+# Controls the default issue type for newly created issues in Jira.
+# See JIRA.get_issue_from_jira() method
+JIRA_ISSUE_TYPE = "Bug"
+
+# Controls the default Tracker in which Redmine issues will be automatically created
+# via 1-click integration.
+REDMINE_TRACKER_NAME = "Bugs"
+
 
 # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 # ~~ DANGER: Don't change the settings below!
@@ -179,10 +195,6 @@ TCMS_ROOT_PATH = os.path.abspath(
 # to load the internationalization machinery.
 USE_I18N = True
 
-# If you set this to False, Django will not format dates, numbers and
-# calendars according to the current locale.
-USE_L10N = True
-
 # Language code for this installation. All choices can be found here:
 # See https://code.djangoproject.com/ticket/29713
 LANGUAGE_CODE = "en-us"
