@@ -18,7 +18,7 @@ from tcms.testcases.forms import (
     SearchCaseForm,
     TestCaseForm,
 )
-from tcms.testcases.models import TestCase
+from tcms.testcases.models import Template, TestCase
 from tcms.testplans.models import TestPlan
 
 
@@ -63,6 +63,7 @@ class NewCaseView(CreateView):
         context = super().get_context_data(**kwargs)
         context["test_plan"] = plan_from_request_or_none(self.request)
         context["notify_formset"] = kwargs.get("notify_formset") or CaseNotifyFormSet()
+        context["templates"] = Template.objects.all()
         return context
 
     def form_valid(self, form):
@@ -132,11 +133,11 @@ class TestCaseGetView(DetailView):
                     ),
                     (
                         _("Clone"),
-                        reverse("testcases-clone") + "?case=%d" % self.object.pk,
+                        reverse("testcases-clone") + f"?c={self.object.pk}",
                     ),
                     (
                         _("History"),
-                        "/admin/testcases/testcase/%d/history/" % self.object.pk,
+                        f"/admin/testcases/testcase/{self.object.pk}/history/",
                     ),
                     ("-", "-"),
                     (
@@ -257,12 +258,16 @@ class CloneTestCaseView(View):
         return HttpResponseRedirect(request.META.get("HTTP_REFERER", "/"))
 
     def get(self, request):
-        if not self._is_request_data_valid(request):
+        if not self._is_request_data_valid(request, "c"):
             return HttpResponseRedirect(request.META.get("HTTP_REFERER", "/"))
 
-        # Initialize the clone case form
-        clone_form = CloneCaseForm(request.GET)
-        clone_form.populate(case_ids=request.GET.getlist("case"))
+        # account for short param names in URI
+        get_params = request.GET.copy()
+        get_params.setlist("case", request.GET.getlist("c"))
+        del get_params["c"]
+
+        clone_form = CloneCaseForm(get_params)
+        clone_form.populate(case_ids=get_params.getlist("case"))
 
         context = {
             "form": clone_form,
@@ -270,10 +275,10 @@ class CloneTestCaseView(View):
         return render(request, self.template_name, context)
 
     @staticmethod
-    def _is_request_data_valid(request):
+    def _is_request_data_valid(request, field_name="case"):
         request_data = getattr(request, request.method)
 
-        if "case" not in request_data:
+        if field_name not in request_data:
             messages.add_message(
                 request, messages.ERROR, _("At least one TestCase is required")
             )
