@@ -193,6 +193,22 @@ $(document).ready(() => {
     )
   })
 
+  // assigned-to-me button
+  document.getElementById('id_assigned_to_me').onchange = () => {
+    const isChecked = $('#id_assigned_to_me').is(':checked')
+    const filterValue = isChecked ? $('#test_run_pk').data('current-user') : ''
+
+    // update the filter widget which will do the actual filtering
+    changeDropdownSelectedItem(
+      '.js-toolbar-filter-options',
+      '#input-filter-button',
+      $('.js-toolbar-filter-options [data-filter-type="assignee__username"]').find('a')[0],
+      $('#toolbar-filter')
+    )
+    $('#toolbar-filter').val(filterValue)
+    $('#toolbar-filter').keyup()
+  }
+
   // email notifications card
   $('#add-cc').click(() => {
     const username = prompt($('#test_run_pk').data('trans-enter-assignee-name-or-email'))
@@ -402,7 +418,7 @@ function bindEvents (selector) {
 function getExpandArea (testExecution) {
   const container = $(`.test-execution-${testExecution.id}`)
 
-  container.find('.test-execution-information .run-date').html(testExecution.close_date || '-')
+  container.find('.test-execution-information .run-date').html(testExecution.stop_date || '-')
   container.find('.test-execution-information .build').html(testExecution.build__name)
   container.find('.test-execution-information .text-version').html(testExecution.case_text_version)
 
@@ -595,7 +611,7 @@ function renderAdditionalInformation (testRunId, execution) {
             row.find('.test-execution-category').html(testCase.category__name)
 
             const isAutomatedElement = row.find('.test-execution-automated')
-            const isAutomatedIcon = testCase.is_automated ? 'fa-cog' : 'fa-thumbs-up'
+            const isAutomatedIcon = testCase.is_automated ? 'fa-cog' : 'fa-hand-paper-o'
             const isAutomatedAttr = testCase.is_automated ? isAutomatedElement.data('automated') : isAutomatedElement.data('manual')
             isAutomatedElement.addClass(isAutomatedIcon)
             isAutomatedElement.attr('title', isAutomatedAttr)
@@ -671,6 +687,7 @@ function renderTestExecutionRow (testExecution) {
 
   template.find('.test-execution-checkbox').data('test-execution-id', testExecution.id)
   template.find('.test-execution-checkbox').data('test-execution-case-id', testExecution.case)
+  template.find('.test-execution-element').attr('id', `test-execution-${testExecution.id}`)
   template.find('.test-execution-element').addClass(`test-execution-${testExecution.id}`)
   template.find('.test-execution-element').addClass(`test-execution-case-${testExecution.case}`)
   template.find('.test-execution-info').html(`TE-${testExecution.id}/TC-${testExecution.case}:`)
