@@ -1,15 +1,17 @@
 # Copyright (c) 2020 Alexander Todorov <atodorov@MrSenko.com>
 
 import xml.etree.ElementTree as etree  # nosec: B405
+
 import markdown
 
 
 class StrikeThroughInlineProcessor(markdown.inlinepatterns.InlineProcessor):
     """
-        See https://python-markdown.github.io/extensions/api/#example_3
+    See https://python-markdown.github.io/extensions/api/#example_3
     """
+
     def handleMatch(self, m, data):
-        element = etree.Element('s')
+        element = etree.Element("s")
         element.text = m.group(1)
         return element, m.start(0), m.end(0)
 
@@ -17,9 +19,7 @@ class StrikeThroughInlineProcessor(markdown.inlinepatterns.InlineProcessor):
 class StrikeThroughExtension(markdown.extensions.Extension):
     def extendMarkdown(self, md):
         md.inlinePatterns.register(
-            StrikeThroughInlineProcessor(r'~~(.*?)~~', md),
-            's',
-            175
+            StrikeThroughInlineProcessor(r"~~(.*?)~~", md), "s", 175
         )
 
 
